/********************************************************************
*
*    DESCRIPTION:Copyright(c) 2015-2020 Xiamen Yealink Network Technology Co,.Ltd
*
*    AUTHOR:
*
*    HISTORY:
*
*    DATE:2015-05-06
*
*******************************************************************/
#ifndef _YL_ENCRYPT_H_
#define _YL_ENCRYPT_H_

#ifdef __cplusplus
extern "C"
{
#endif

    /*
     * @brief  :  Inspection Library Function
     *
     * @param buf:     [in]     Contents of Hope Check
     * @param len:     [in]     The buf len
     *
     * @return : 0 is success, otherwise failed.
     *
     */
    int Yealink_Check_AesKey(const char* buf, int len);

    /*
     * @brief  :  Aes encrypt/decrypt text
     *
     * @param pszKey:     [in]     secret key
     * @param pszByte_in: [in]     will be encrypted character pointer
     * @param nSize_in:   [in]     will be encrypted character length
     * @param pszByte_out:[out]    output encryption result
     * @param nSize_out:  [in/out] input buf size, output encrypted text size
     *
     * @return : 0 is success, otherwise failed.
     * @Note : The Yealink_DeEncode is only valid in DEBUG version
     *
     */
    int Yealink_Encode(const char *pszKey, const char *pszByte_in, int nSize_in, char *pszByte_out, int *nSize_out);
    int Yealink_DeEncode(const char *pszKey, const char *pszByte_in, int nSize_in, char *pszByte_out, int *nSize_out);

    /*
     * @brief  :  Basic64 encrypt/decrypt text
     *
     * @param pszStr_in:    [in]     Content to be encrypted/decrypted
     * @param pszStrLen_in: [in]     The pszStr_in len
     * @param pszStr_out:   [in]     The buf to save ciphertext/plaintext
     * @param pszStrLen_out:[out]    pszStr_out size
     *
     * @return : 0 is success, otherwise failed.
     *
     */
    int Yealink_BASE64_Encrypt(const unsigned char *pszStr_in, int pszStrLen_in, char *pszStr_out, int pszStrLen_out);
    int Yealink_BASE64_Decrypt(const unsigned char *pszStr_in, int pszStrLen_in, char *pszStr_out, int pszStrLen_out);

    /*
     * @brief  :  RSA encrypt text
     *
     * @param pszPubKey:    [in]     The RSA pubilc key file
     * @param pszStr_in:    [in]     Content to be encrypted
     * @param pszStrLen_in: [in]     The pszStr_in len
     * @param pszStr_out:   [in]     The buf to save ciphertext
     * @param pszStrLen_out:[out]    pszStr_out size
     *
     * @return : 0 is success, otherwise failed.
     *
     */
    int Yealink_RSA_Encrypt(const char *pszPubKey, const char *pszStr_in, int pszStrLen_in, char *pszStr_out, int pszStrLen_out);

    /*
     * @brief  :  RSA encrypt text
     *
     * @param pszPubKey:    [in]     The RSA pubilc key file
     * @param pszAesKey:    [in]     secret key
     * @param pszCfgIn:     [in]     Files requiring encryption
     * @param pszCfgOut:    [in]     Encrypted File Storage Path
     *
     * @return : 0 is success, otherwise failed.
     *
     */
    int Yealink_Build_RSA_Config(const char *pszPubKey, const char *pszAesKey, const char *pszCfgIn, const char *pszCfgOut);
    int Yealink_Build_CMPT_Config(const char *pszPubKey, const char *pszAesKey, const char *pszCfgIn, const char *pszCfgOut);

    /*
     * @brief  : get wrong information when something goes wrong
     *
     * @return : error msg
     *
     */
    const char *Yealink_Info();

#ifdef __cplusplus
}
#endif

#endif	//end _YL_ENCRYPT_H_
